@@ -14,7 +14,7 @@ using namespace std;
 
 extern "C" {
 
-  SEXP spMvGLM_AMCMC(SEXP Y_r, SEXP X_r, SEXP p_r, SEXP n_r, SEXP m_r, SEXP coordsD_r,SEXP family_r,
+  SEXP spMvGLM_AMCMC(SEXP Y_r, SEXP X_r, SEXP p_r, SEXP n_r, SEXP m_r, SEXP coordsD_r,SEXP family_r, SEXP weights_r,
 		     SEXP betaPrior_r, SEXP betaNorm_r, SEXP KIW_r, SEXP nuUnif_r, SEXP phiUnif_r,
 		     SEXP phiStarting_r, SEXP AStarting_r, SEXP nuStarting_r, SEXP betaStarting_r, SEXP wStarting_r,
 		     SEXP phiTuning_r, SEXP ATuning_r, SEXP nuTuning_r , SEXP betaTuning_r, SEXP wTuning_r,
@@ -55,6 +55,8 @@ extern "C" {
 
     string family = CHAR(STRING_ELT(family_r,0));
 
+    int *weights = INTEGER(weights_r);
+
     //covariance model
     string covModel = CHAR(STRING_ELT(covModel_r,0));
 
@@ -360,7 +362,7 @@ extern "C" {
 	  F77_NAME(dgemv)(ntran, &nm, &p, &one, X, &nm, beta, &incOne, &zero, tmp_nm, &incOne);
 	  
 	  if(family == "binomial"){
-	    logPostCand += logit_logpost(nm, Y, tmp_nm, w);
+	    logPostCand += binomial_logpost(nm, Y, tmp_nm, w, weights);
 	  }else if(family == "poisson"){
 	    logPostCand += poisson_logpost(nm, Y, tmp_nm, w);
 	  }else{
@@ -460,7 +462,7 @@ extern "C" {
 	  F77_NAME(dgemv)(ntran, &nm, &p, &one, X, &nm, beta, &incOne, &zero, tmp_nm, &incOne);
 	  
 	  if(family == "binomial"){
-	    logPostCand += logit_logpost(nm, Y, tmp_nm, w);
+	    logPostCand += binomial_logpost(nm, Y, tmp_nm, w, weights);
 	  }else if(family == "poisson"){
 	    logPostCand += poisson_logpost(nm, Y, tmp_nm, w);
 	  }else{
